use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.006009
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib  ) );
__DATA__
LoadFile
deserialization
deserialize
deserializes
deserializing
die'ing
json
metafiles
serializer
Adam
Kennedy
adamk
David
Golden
dagolden
and
Contributors
Graham
Knop
haarg
Joshua
ben
Jore
jjore
Karen
Etheridge
ether
Neil
Bowers
neil
Ricardo
Signes
rjbs
Steffen
Mueller
smueller
lib
Parse
CPAN
Meta
